@@ -140,25 +140,44 @@ namespace PodSleuth
             if(plist_dict.ContainsKey("FireWireGUID")) {
                 firewire_id = ((PlistString)plist_dict["FireWireGUID"]).Value;
             }
-            
+
             foreach(string img_class in new string [] { "ImageSpecifications", "AlbumArt", "ChapterImageSpecs" }) {
                 if(!plist_dict.ContainsKey(img_class)) {
                     continue;
                 }
+
+                bool added_any = false;
                 
                 PlistDictionary formats = plist_dict[img_class] as PlistDictionary;
-                if(formats == null || formats.Count == 0) {
+                if(formats != null && formats.Count > 0) {
+                    foreach(KeyValuePair<string, PlistObjectBase> kvp in formats) {
+                        try {
+                            ImageFormat format = new ImageFormat((PlistDictionary)kvp.Value, img_class);
+                            image_formats.Add(format);
+                            added_any = true;
+                        } catch {
+                        }
+                    }
+                } else {
+                    // In 4th gen Nanos, the plist format was changed to list the image
+                    // types supported in an array instead of as entries in a dict.
+                    PlistArray formats_array = plist_dict[img_class] as PlistArray;
+                    if (formats_array != null) {
+                        foreach(PlistObjectBase val in formats_array) {
+                            try {
+                                ImageFormat format = new ImageFormat((PlistDictionary)val, img_class);
+                                image_formats.Add(format);
+                                added_any = true;
+                            } catch {
+                            }
+                        }
+                    }
+                }
+
+                if(!added_any) {
                     continue;
                 }
                 
-                foreach(KeyValuePair<string, PlistObjectBase> kvp in formats) {
-                    try {
-				        ImageFormat format = new ImageFormat((PlistDictionary)kvp.Value, img_class);
-				        image_formats.Add(format);
-				    } catch {
-				    }
-				}
-                
                 switch(img_class) {
                     case "ImageSpecifications": photos_supported = true; break;
                     case "AlbumArt": album_art_supported = true; break;
@@ -194,9 +213,11 @@ namespace PodSleuth
             }
             
             string model = sysinfo["ModelNumStr"];
-            
-            model = model.Substring(1);
-            model = model.Substring(0, 4);
+            if (model != null && model.Length >= 5) {
+                model = model.Substring(1);
+                model = model.Substring(0, 4);
+            }
+
             return model;
         }
         
